package restclient;

import javax.json.*;

/**
 * JSON-REST-Client zur Wettervorhersage,
 * {@link "https://www.metaweather.com/de/"}
 * {@link "https://www.metaweather.com/api/"}
 * {@link "https://www.metaweather.com/api/location/search/?query=Cologne"}
 * {@link "https://www.metaweather.com/api/location/667931"}
 */
public class WetterRestClient
{
   public static void main( String[] args )
   {
      final String urlLocation = "https://www.metaweather.com/api/location/search/?query=";
      final String urlWetter   = "https://www.metaweather.com/api/location/";

      if( args == null || args.length == 0 ) {
         System.out.println( "\nBitte eine Stadt als Kommandozeilenparameter uebergeben, z.B.: Cologne." );
         return;
      }
      JsonArray jsonLocations = JsonObjectFromUrlUtil.getJsonArrayFromUrl( urlLocation + args[0] );
      if( jsonLocations.isEmpty() ) {
         System.out.println( "\n" + args[0] + " wurde nicht gefunden." );
         return;
      }
      JsonObject loc = jsonLocations.getValuesAs( JsonObject.class ).get( 0 );
      JsonNumber woeid = loc.getJsonNumber( "woeid" );
      System.out.println( "\n\n" + loc.getString( "title" ) +
            " (woeid=" + woeid + ", latt_long=" + loc.getString( "latt_long" ) + "):" );

      JsonArray weather = JsonObjectFromUrlUtil.getJsonObjectFromUrl( urlWetter + woeid ).getJsonArray( "consolidated_weather" );
      weather.getValuesAs( JsonObject.class ).forEach(
            e -> System.out.println( "  " + e.getString( "applicable_date" ) +
                 ":  "    + Math.round( e.getJsonNumber( "min_temp" ).doubleValue() ) +
                 "° bis " + Math.round( e.getJsonNumber( "max_temp" ).doubleValue() ) + "°, " +
                 e.getString( "weather_state_name" ) ) );
      System.out.println( "\n" );
   }
}
